@@ -2,6 +2,10 @@ from collections import OrderedDict
 
 import hostlist
 
+javascript_repo = [
+    'cloudmesh-javascript'
+]
+
 cms = [
     'cloudmesh-common',
     'cloudmesh-cmd5',
@@ -83,12 +87,15 @@ repos = OrderedDict({
         'cloudmesh-storage',
         'cloudmesh-cmsd',
         'cloudmesh-multipass',
-        'cloudmesh-manual'
-
+        'cloudmesh-manual',
     ],
 
     'cloud': cloud,
 
+    'javascript': cloud + [
+        'cloudmesh-javascript'
+    ],
+
     'gui': cloud + [
         'cloudmesh-admin',
         'cloudmesh-gui'
@@ -116,7 +123,9 @@ repos = OrderedDict({
     'pi': cms +[
         'cloudmesh-admin',
         'cloudmesh-inventory',
-        'cloudmesh-pi-cluster'
+        'cloudmesh-cloud',
+        'cloudmesh-pi-cluster',
+        'cloudmesh-pi-burn'
     ],
 
     'cluster': cms + [
@@ -156,12 +165,7 @@ repos = OrderedDict({
         'cloudmesh-inventory',
         'cloudmesh-admin',
         'cloudmesh-cmsd',
-        'cloudmesh-azure',
-        'cloudmesh-aws',
-        'cloudmesh-openstack',
-        'cloudmesh-google',
-        'cloudmesh-oracle',
-        'cloudmesh-multipass'
+        'cloudmesh-compute',
 #        'cloudmesh-storage',
     ],
 
@@ -203,17 +207,21 @@ repos = OrderedDict({
     ],
 
     'compute': cloud + [
-        'cloudmesh-aws',
         'cloudmesh-azure',
-        'cloudmesh-apoenstack',
-        'cloudmesh-google'
+        'cloudmesh-aws',
+        'cloudmesh-openstack',
+        'cloudmesh-google',
+        'cloudmesh-oracle',
+        'cloudmesh-multipass'
     ],
 
     'provider': cloud + [
-        'cloudmesh-aws',
         'cloudmesh-azure',
+        'cloudmesh-aws',
         'cloudmesh-openstack',
-        'cloudmesh-google'
+        'cloudmesh-google',
+        'cloudmesh-oracle',
+        'cloudmesh-multipass'
     ],
     'frugal': cloud + [
         'cloudmesh-frugal'
@@ -252,13 +260,13 @@ repos = OrderedDict({
         'cloudmesh-google',
         'cloudmesh-gui',
         'cloudmesh-iu',
+        'cloudmesh-javascript',
         'cloudmesh-nist',
         'cloudmesh-nn',
         'cloudmesh-notebooks',
         'cloudmesh-openapi',
         'cloudmesh-oracle',
         'cloudmesh-redshift',
-        'cloudmesh-stopwatch',
         'cloudmesh-storage',
         'cloudmesh-workflow',
         'cloudmesh-storagelifecycle',
