@@ -291,8 +291,10 @@ class Git(object):
 
         repos = OrderedSet(repos)
 
+
         for repo in repos:
             StopWatch.start("install " + repo)
+
             if dev:
                 banner(f"dev install -> {repo}")
 
@@ -302,7 +304,6 @@ class Git(object):
                 os.chdir(repo)
                 os.system("pip install -e .")
                 os.chdir("../")
-                StopWatch.status("install " + repo, True)
 
             else:
                 banner(f"install -> {repo}")
@@ -311,9 +312,20 @@ class Git(object):
                 print()
 
                 os.system("pip install {repo}".format(repo=repo))
-                StopWatch.status("install " + repo, True)
+
+            if repo in javascript_repo:
+                banner(f"javascript install -> {repo}")
+
+                Console.info(f"pip install -e .: {repo}")
+                print()
+
+                os.chdir(repo)
+                os.system("yarn")
+                os.chdir("../")
+
 
             StopWatch.stop("install " + repo)
+            StopWatch.status("install " + repo, True)
 
 
 # git clone https://github.com/cloudmesh/get.git
